@@ -3,17 +3,37 @@ from . import nlp
 import os
 from rich import inspect, reconfigure, get_console
 from rich.console import Console
-from contextlib import redirect_stdout
+from contextlib import redirect_stdout, redirect_stderr, nullcontext, ExitStack
 from textwrap import dedent
 from .timeout import timeout
+import dataclasses
 
 
-def eval_single(path, category=None, override_prompt=None, **kwargs):
+def eval_single(path, category=None, override_prompt=None, quiet=False, **kwargs):
     with open(path, 'r') as f:
         config = yaml.safe_load(f.read())
     try:
-        prompt = nlp.prompts[config['context']
-                             ] if override_prompt is None else nlp.prompts[override_prompt]
+        if override_prompt is None:
+            prompt = nlp.prompts[config['context']]
+        # special ones
+        elif override_prompt == 'insert':
+            pkey = config['context'] + '-insert'
+            if pkey in nlp.prompts:
+                prompt = nlp.prompts[pkey]
+            else:
+                prompt = nlp.prompts[config['context']]
+
+        elif override_prompt.startswith('header:'):
+            pkey = config['context'] + '-insert'
+            if pkey in nlp.prompts:
+                prompt = nlp.prompts[pkey]
+            else:
+                prompt = nlp.prompts[config['context']]
+            prompt = dataclasses.replace(prompt)
+            prompt.text = override_prompt.split(
+                'header:')[-1] + prompt.text
+        else:
+            prompt = nlp.prompts[override_prompt]
         context = nlp.Context(
             name=config['name'], prompt=prompt)
     except Exception as e:
@@ -38,14 +58,15 @@ def eval_single(path, category=None, override_prompt=None, **kwargs):
     dir = os.path.dirname(path)
     with open(os.path.join(dir, config['prompt']), 'r') as f:
         query = f.read()
-    # TODO Better way?
-    # Make it so we can only get one function
+        # TODO: More transparent way to do this
+        if override_prompt is None or 'insert' not in override_prompt:
+            query = query.split('[insert]')[0]
+
     if context.prompt.stop is None:
         context.prompt.stop = ['def']
     elif 'def' not in context.prompt.stop:
         context.prompt.stop = ['def'] + context.prompt.stop
     context = nlp.code_completion(query, context, **kwargs)
-
     if not 'test' in config or config['test'] is None:
         result = {'name': config['name'], 'context': context, 'result': None}
         return result, ''
@@ -60,9 +81,15 @@ def eval_single(path, category=None, override_prompt=None, **kwargs):
         g = {}
         success = True
         try:
-            with redirect_stdout(None):
-                with timeout(seconds=10):
-                    exec(dir_string + r + '\n' + test_code, g)
+            if quiet:
+                cms = redirect_stdout(None), redirect_stderr(
+                    None), timeout(seconds=10)
+            else:
+                cms = (timeout(seconds=10),)
+            with ExitStack() as stack:
+                for c in cms:
+                    stack.enter_context(c)
+                exec(dir_string + r + '\n' + test_code, g)
             if 'result' not in g:
                 exceptions.append(
                     f'\nYou must have variable `result` defined. \n')
